# AI-Parade Toolkit

The ai-parade toolkit could be used in 2 ways:

1. To [add model into ai-parade](docs/addModel/index.md)
2. To [use model(s)](docs/use/index.md)

## Contributing

[See here](./docs/contribute/index.md)
